@@ -258,9 +258,7 @@ def setup(
 
     remove_multicollinearity: bool, default = False
         When set to True, features with the inter-correlations higher than the defined 
-        threshold are removed. When two features are highly correlated with each other, 
-        the feature that is less correlated with the target variable is removed. 
-
+        threshold are removed. Only considers numeric features.
 
     multicollinearity_threshold: float, default = 0.9
         Threshold for correlated features. Ignored when ``remove_multicollinearity``
@@ -595,7 +593,7 @@ def plot_model(
     label: bool = False,
     scale: float = 1,
     save: bool = False,
-    display_format: Optional[str] = None
+    display_format: Optional[str] = None,
 ):
 
     """
@@ -658,7 +656,13 @@ def plot_model(
 
     """
     return pycaret.internal.tabular.plot_model(
-        model, plot=plot, feature_name=feature, label=label, scale=scale, save=save, display_format=display_format
+        model,
+        plot=plot,
+        feature_name=feature,
+        label=label,
+        scale=scale,
+        save=save,
+        display_format=display_format,
     )
 
 
@@ -904,11 +908,10 @@ def predict_model(model, data: pd.DataFrame) -> pd.DataFrame:
 def deploy_model(
     model, model_name: str, authentication: dict, platform: str = "aws",
 ):
-
     """
     This function deploys the transformation pipeline and trained model on cloud.
-    
-    
+
+
     Example
     -------
     >>> from pycaret.datasets import get_data
@@ -916,67 +919,71 @@ def deploy_model(
     >>> from pycaret.clustering import *
     >>> exp_name = setup(data = jewellery)
     >>> kmeans = create_model('kmeans')
+    >>> # sets appropriate credentials for the platform as environment variables
+    >>> import os
+    >>> os.environ["AWS_ACCESS_KEY_ID"] = str("foo")
+    >>> os.environ["AWS_SECRET_ACCESS_KEY"] = str("bar")
     >>> deploy_model(model = kmeans, model_name = 'kmeans-for-deployment', platform = 'aws', authentication = {'bucket' : 'S3-bucket-name'})
-        
+
 
     Amazon Web Service (AWS) users:
-        To deploy a model on AWS S3 ('aws'), environment variables must be set in your
-        local environment. To configure AWS environment variables, type ``aws configure`` 
-        in the command line. Following information from the IAM portal of amazon console 
-        account is required:
+        To deploy a model on AWS S3 ('aws'), the credentials have to be passed. The easiest way is to use environment
+        variables in your local environment. Following information from the IAM portal of amazon console account
+        are required:
 
         - AWS Access Key ID
         - AWS Secret Key Access
-        - Default Region Name (can be seen under Global settings on your AWS console)
 
-        More info: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-envvars.html
+        More info: https://boto3.amazonaws.com/v1/documentation/api/latest/guide/credentials.html#environment-variables
 
 
     Google Cloud Platform (GCP) users:
-        To deploy a model on Google Cloud Platform ('gcp'), project must be created 
-        using command line or GCP console. Once project is created, you must create 
-        a service account and download the service account key as a JSON file to set 
-        environment variables in your local environment. 
+        To deploy a model on Google Cloud Platform ('gcp'), project must be created
+        using command line or GCP console. Once project is created, you must create
+        a service account and download the service account key as a JSON file to set
+        environment variables in your local environment.
 
         More info: https://cloud.google.com/docs/authentication/production
 
-    
+
     Microsoft Azure (Azure) users:
         To deploy a model on Microsoft Azure ('azure'), environment variables for connection
         string must be set in your local environment. Go to settings of storage account on
-        Azure portal to access the connection string required. 
+        Azure portal to access the connection string required.
+
+        - AZURE_STORAGE_CONNECTION_STRING (required as environment variable)
 
         More info: https://docs.microsoft.com/en-us/azure/storage/blobs/storage-quickstart-blobs-python?toc=%2Fpython%2Fazure%2FTOC.json
 
 
     model: scikit-learn compatible object
         Trained model object
-    
+
 
     model_name: str
         Name of model.
-    
+
 
     authentication: dict
         Dictionary of applicable authentication tokens.
 
         When platform = 'aws':
-        {'bucket' : 'S3-bucket-name'}
+        {'bucket' : 'S3-bucket-name', 'path': (optional) folder name under the bucket}
 
         When platform = 'gcp':
         {'project': 'gcp-project-name', 'bucket' : 'gcp-bucket-name'}
 
         When platform = 'azure':
         {'container': 'azure-container-name'}
-    
+
 
     platform: str, default = 'aws'
         Name of the platform. Currently supported platforms: 'aws', 'gcp' and 'azure'.
-    
+
 
     Returns:
         None
-    
+
     """
 
     return pycaret.internal.tabular.deploy_model(
@@ -987,7 +994,9 @@ def deploy_model(
     )
 
 
-def save_model(model, model_name: str, model_only: bool = False, verbose: bool = True):
+def save_model(
+    model, model_name: str, model_only: bool = False, verbose: bool = True, **kwargs
+):
 
     """
     This function saves the transformation pipeline and trained model object 
@@ -1021,13 +1030,21 @@ def save_model(model, model_name: str, model_only: bool = False, verbose: bool =
         Success message is not printed when verbose is set to False.
 
 
+    **kwargs: 
+        Additional keyword arguments to pass to joblib.dump().
+
+
     Returns:
         Tuple of the model object and the filename.
 
     """
 
     return pycaret.internal.tabular.save_model(
-        model=model, model_name=model_name, model_only=model_only, verbose=verbose
+        model=model,
+        model_name=model_name,
+        model_only=model_only,
+        verbose=verbose,
+        **kwargs,
     )
 
 
@@ -1061,7 +1078,7 @@ def load_model(
         dictionary of applicable authentication tokens.
 
         when platform = 'aws':
-        {'bucket' : 'S3-bucket-name'}
+        {'bucket' : 'Name of Bucket on S3', 'path': (optional) folder name under the bucket}
 
         when platform = 'gcp':
         {'project': 'gcp-project-name', 'bucket' : 'gcp-bucket-name'}
