@@ -3,6 +3,8 @@
 # License: MIT
 
 import logging
+import traceback
+import os
 
 
 def get_logger() -> logging.Logger:
@@ -15,13 +17,19 @@ def get_logger() -> logging.Logger:
 
 def create_logger() -> logging.Logger:
     logger = logging.getLogger("logs")
-    logger.setLevel(logging.DEBUG)
+    level = os.getenv("PYCARET_CUSTOM_LOGGING_LEVEL", "DEBUG")
+    logger.setLevel(level)
 
     # create console handler and set level to debug
     if logger.hasHandlers():
         logger.handlers.clear()
 
-    ch = logging.FileHandler("logs.log")
+    try:
+        ch = logging.FileHandler("logs.log")
+    except:
+        print("Could not attach a FileHandler to the logger! No logs will be saved.")
+        traceback.print_exc()
+        ch = logging.NullHandler()
     ch.setLevel(logging.DEBUG)
 
     # create formatter
